# -*- coding: utf-8 -*-
import logging
if __name__ == '__main__':
    logging.basicConfig()
_log = logging.getLogger(__name__)
from pyxb.exceptions_ import *
import unittest
import pyxb.binding.datatypes as xsd

class Test_QName (unittest.TestCase):
    def testValid (self):
        valid = [ 'schema', 'xs:something', 'with.dots' ]
        for f in valid:
            self.assertEqual(f, xsd.QName(f))

    def testInvalid (self):
        invalid = [ '-NonName', '-also:-not', 'and:-not', 'too:many:colons', ' whitespace ' ]
        for f in invalid:
            try:
                xsd.QName(f)
                print 'Unexpected pass with %s' % (f,)
            except:
                pass
            self.assertRaises(SimpleTypeValueError, xsd.QName, f)

if __name__ == '__main__':
    unittest.main()
